@@ -45,19 +45,20 @@ from securesystemslib.gpg.util import (get_version, is_version_fully_supported,
     get_hashing_class, parse_packet_header, parse_subpacket_header)
 from securesystemslib.gpg.rsa import create_pubkey as rsa_create_pubkey
 from securesystemslib.gpg.dsa import create_pubkey as dsa_create_pubkey
+from securesystemslib.gpg.eddsa import create_pubkey as eddsa_create_pubkey
 from securesystemslib.gpg.common import (parse_pubkey_payload,
     parse_pubkey_bundle, get_pubkey_bundle, _assign_certified_key_info,
     _get_verified_subkeys, parse_signature_packet)
 from securesystemslib.gpg.constants import (SHA1, SHA256, SHA512,
     GPG_EXPORT_PUBKEY_COMMAND, PACKET_TYPE_PRIMARY_KEY, PACKET_TYPE_USER_ID,
-    PACKET_TYPE_USER_ATTR, PACKET_TYPE_SUB_KEY)
+    PACKET_TYPE_USER_ATTR, PACKET_TYPE_SUB_KEY, HAVE_GPG)
 from securesystemslib.gpg.exceptions import (PacketParsingError,
     PacketVersionNotSupportedError, SignatureAlgorithmNotSupportedError,
     KeyNotFoundError, CommandError, KeyExpirationError)
 from securesystemslib.formats import GPG_PUBKEY_SCHEMA
 
 
-@unittest.skipIf(os.getenv("TEST_SKIP_GPG"), "gpg not found")
+@unittest.skipIf(not HAVE_GPG, "gpg not found")
 class TestUtil(unittest.TestCase):
   """Test util functions. """
   def test_version_utils_return_types(self):
@@ -170,7 +171,7 @@ class TestUtil(unittest.TestCase):
       self.assertEqual(result, expected[idx])
 
 
-@unittest.skipIf(os.getenv("TEST_SKIP_GPG"), "gpg not found")
+@unittest.skipIf(not HAVE_GPG, "gpg not found")
 class TestCommon(unittest.TestCase):
   """Test common functions of the securesystemslib.gpg module. """
   @classmethod
@@ -470,7 +471,7 @@ class TestCommon(unittest.TestCase):
           "'{}' not in '{}'".format(expected_error_str, str(ctx.exception)))
 
 
-@unittest.skipIf(os.getenv("TEST_SKIP_GPG"), "gpg not found")
+@unittest.skipIf(not HAVE_GPG, "gpg not found")
 class TestGPGRSA(unittest.TestCase):
   """Test signature creation, verification and key export from the gpg
   module"""
@@ -624,7 +625,7 @@ class TestGPGRSA(unittest.TestCase):
         "\ngot:      {}".format(expected, ctx.exception))
 
 
-@unittest.skipIf(os.getenv("TEST_SKIP_GPG"), "gpg not found")
+@unittest.skipIf(not HAVE_GPG, "gpg not found")
 class TestGPGDSA(unittest.TestCase):
   """ Test signature creation, verification and key export from the gpg
   module """
@@ -654,31 +655,31 @@ class TestGPGDSA(unittest.TestCase):
   def test_export_pubkey(self):
     """ export a public key and make sure the parameters are the right ones:
 
-      since there's very little we can do to check rsa key parameters are right
-      we pre-exported the public key to an ssh key, which we can load with
-      cryptography for the sake of comparison """
+      since there's very little we can do to check key parameters are right
+      we pre-exported the public key to an x.509 SubjectPublicKeyInfo key,
+      which we can load with cryptography for the sake of comparison """
 
     # export our gpg key, using our functions
     key_data = export_pubkey(self.default_keyid, homedir=self.gnupg_home)
     our_exported_key = dsa_create_pubkey(key_data)
 
-    # load the equivalent ssh key, and make sure that we get the same RSA key
-    # parameters
-    ssh_key_basename = "{}.ssh".format(self.default_keyid)
-    ssh_key_path = os.path.join(self.gnupg_home, ssh_key_basename)
-    with open(ssh_key_path, "rb") as fp:
+    # load same key, pre-exported with 3rd-party tooling
+    pem_key_basename = "{}.pem".format(self.default_keyid)
+    pem_key_path = os.path.join(self.gnupg_home, pem_key_basename)
+    with open(pem_key_path, "rb") as fp:
       keydata = fp.read()
 
-    ssh_key = serialization.load_ssh_public_key(keydata,
+    pem_key = serialization.load_pem_public_key(keydata,
         backends.default_backend())
 
-    self.assertEqual(ssh_key.public_numbers().y,
+    # make sure keys match
+    self.assertEqual(pem_key.public_numbers().y,
         our_exported_key.public_numbers().y)
-    self.assertEqual(ssh_key.public_numbers().parameter_numbers.g,
+    self.assertEqual(pem_key.public_numbers().parameter_numbers.g,
         our_exported_key.public_numbers().parameter_numbers.g)
-    self.assertEqual(ssh_key.public_numbers().parameter_numbers.q,
+    self.assertEqual(pem_key.public_numbers().parameter_numbers.q,
         our_exported_key.public_numbers().parameter_numbers.q)
-    self.assertEqual(ssh_key.public_numbers().parameter_numbers.p,
+    self.assertEqual(pem_key.public_numbers().parameter_numbers.p,
         our_exported_key.public_numbers().parameter_numbers.p)
 
   def test_gpg_sign_and_verify_object_with_default_key(self):
@@ -708,5 +709,60 @@ class TestGPGDSA(unittest.TestCase):
     self.assertFalse(verify_signature(signature, key_data, wrong_data))
 
 
+
+@unittest.skipIf(not HAVE_GPG, "gpg not found")
+class TestGPGEdDSA(unittest.TestCase):
+  """ Test signature creation, verification and key export from the gpg
+  module """
+
+  default_keyid = "4E630F84838BF6F7447B830B22692F5FEA9E2DD2"
+
+  @classmethod
+  def setUpClass(self):
+    # Create directory to run the tests without having everything blow up
+    self.working_dir = os.getcwd()
+    self.test_dir = os.path.realpath(tempfile.mkdtemp())
+    self.gnupg_home = os.path.join(self.test_dir, "dsa")
+
+    # Find keyrings
+    keyrings = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "gpg_keyrings", "eddsa")
+
+    shutil.copytree(keyrings, self.gnupg_home)
+    os.chdir(self.test_dir)
+
+  @classmethod
+  def tearDownClass(self):
+    """Change back to initial working dir and remove temp test directory. """
+    os.chdir(self.working_dir)
+    shutil.rmtree(self.test_dir)
+
+  def test_gpg_sign_and_verify_object_with_default_key(self):
+    """Create a signature using the default key on the keyring """
+
+    test_data = b'test_data'
+    wrong_data = b'something malicious'
+
+    signature = create_signature(test_data, homedir=self.gnupg_home)
+    key_data = export_pubkey(self.default_keyid, homedir=self.gnupg_home)
+
+    self.assertTrue(verify_signature(signature, key_data, test_data))
+    self.assertFalse(verify_signature(signature, key_data, wrong_data))
+
+
+  def test_gpg_sign_and_verify_object_with_specific_key(self):
+    """Create a signature using a specific key on the keyring """
+
+    test_data = b'test_data'
+    wrong_data = b'something malicious'
+
+    signature = create_signature(test_data, keyid=self.default_keyid,
+        homedir=self.gnupg_home)
+    key_data = export_pubkey(self.default_keyid, homedir=self.gnupg_home)
+
+    self.assertTrue(verify_signature(signature, key_data, test_data))
+    self.assertFalse(verify_signature(signature, key_data, wrong_data))
+
+
 if __name__ == "__main__":
   unittest.main()
