@@ -28,7 +28,6 @@ from __future__ import unicode_literals
 import os
 import time
 import datetime
-import logging
 import tempfile
 import json
 import shutil
@@ -43,15 +42,13 @@ if sys.version_info >= (3, 3):
 else:
   import mock
 
-import securesystemslib.formats
+import securesystemslib.exceptions
 import securesystemslib.formats
 import securesystemslib.hash
 import securesystemslib.interface as interface
 
 import six
 
-logger = logging.getLogger('securesystemslib_test_interface')
-
 
 
 class TestInterfaceFunctions(unittest.TestCase):
@@ -221,8 +218,8 @@ class TestInterfaceFunctions(unittest.TestCase):
     # Non-existent key file.
     nonexistent_keypath = os.path.join(temporary_directory,
         'nonexistent_keypath')
-    self.assertRaises(IOError, interface.import_rsa_privatekey_from_file,
-        nonexistent_keypath, 'pw')
+    self.assertRaises(securesystemslib.exceptions.StorageError,
+        interface.import_rsa_privatekey_from_file, nonexistent_keypath, 'pw')
 
     # Invalid key file argument.
     invalid_keyfile = os.path.join(temporary_directory, 'invalid_keyfile')
@@ -255,8 +252,8 @@ class TestInterfaceFunctions(unittest.TestCase):
     # Non-existent key file.
     nonexistent_keypath = os.path.join(temporary_directory,
         'nonexistent_keypath')
-    self.assertRaises(IOError, interface.import_rsa_publickey_from_file,
-        nonexistent_keypath)
+    self.assertRaises(securesystemslib.exceptions.StorageError,
+        interface.import_rsa_publickey_from_file, nonexistent_keypath)
 
     # Invalid key file argument.
     invalid_keyfile = os.path.join(temporary_directory, 'invalid_keyfile')
@@ -377,8 +374,8 @@ class TestInterfaceFunctions(unittest.TestCase):
     # Non-existent key file.
     nonexistent_keypath = os.path.join(temporary_directory,
         'nonexistent_keypath')
-    self.assertRaises(IOError, interface.import_ed25519_publickey_from_file,
-        nonexistent_keypath)
+    self.assertRaises(securesystemslib.exceptions.StorageError,
+        interface.import_ed25519_publickey_from_file, nonexistent_keypath)
 
     # Invalid key file argument.
     invalid_keyfile = os.path.join(temporary_directory, 'invalid_keyfile')
@@ -429,8 +426,9 @@ class TestInterfaceFunctions(unittest.TestCase):
     # Non-existent key file.
     nonexistent_keypath = os.path.join(temporary_directory,
         'nonexistent_keypath')
-    self.assertRaises(IOError, interface.import_ed25519_privatekey_from_file,
-        nonexistent_keypath, 'pw')
+    self.assertRaises(securesystemslib.exceptions.StorageError,
+        interface.import_ed25519_privatekey_from_file, nonexistent_keypath,
+        'pw')
 
     # Invalid key file argument.
     invalid_keyfile = os.path.join(temporary_directory, 'invalid_keyfile')
@@ -443,10 +441,10 @@ class TestInterfaceFunctions(unittest.TestCase):
     # Invalid private key imported (contains unexpected keytype.)
     imported_ed25519_key['keytype'] = 'invalid_keytype'
 
-    # Use 'pyca_crypto_keys.py' to bypass the key format validation performed
+    # Use 'rsa_keys.py' to bypass the key format validation performed
     # by 'keys.py'.
     salt, iterations, derived_key = \
-      securesystemslib.pyca_crypto_keys._generate_derived_key('pw')
+      securesystemslib.rsa_keys._generate_derived_key('pw')
 
     # Store the derived key info in a dictionary, the object expected
     # by the non-public _encrypt() routine.
@@ -456,7 +454,7 @@ class TestInterfaceFunctions(unittest.TestCase):
     # Convert the key object to json string format and encrypt it with the
     # derived key.
     encrypted_key = \
-      securesystemslib.pyca_crypto_keys._encrypt(json.dumps(imported_ed25519_key),
+      securesystemslib.rsa_keys._encrypt(json.dumps(imported_ed25519_key),
           derived_key_information)
 
     with open(ed25519_keypath, 'wb') as file_object:
@@ -529,8 +527,8 @@ class TestInterfaceFunctions(unittest.TestCase):
     # Non-existent key file.
     nonexistent_keypath = os.path.join(temporary_directory,
         'nonexistent_keypath')
-    self.assertRaises(IOError, interface.import_ecdsa_publickey_from_file,
-        nonexistent_keypath)
+    self.assertRaises(securesystemslib.exceptions.StorageError,
+        interface.import_ecdsa_publickey_from_file, nonexistent_keypath)
 
     # Invalid key file argument.
     invalid_keyfile = os.path.join(temporary_directory, 'invalid_keyfile')
@@ -579,8 +577,8 @@ class TestInterfaceFunctions(unittest.TestCase):
     # Test invalid argument.
     # Non-existent key file.
     nonexistent_keypath = os.path.join(temporary_directory, 'nonexistent_keypath')
-    self.assertRaises(IOError, interface.import_ecdsa_privatekey_from_file,
-        nonexistent_keypath, 'pw')
+    self.assertRaises(securesystemslib.exceptions.StorageError,
+        interface.import_ecdsa_privatekey_from_file, nonexistent_keypath, 'pw')
 
     # Invalid key file argument.
     invalid_keyfile = os.path.join(temporary_directory, 'invalid_keyfile')
@@ -593,10 +591,10 @@ class TestInterfaceFunctions(unittest.TestCase):
     # Invalid private key imported (contains unexpected keytype.)
     imported_ecdsa_key['keytype'] = 'invalid_keytype'
 
-    # Use 'pyca_crypto_keys.py' to bypass the key format validation performed
+    # Use 'rsa_keys.py' to bypass the key format validation performed
     # by 'keys.py'.
     salt, iterations, derived_key = \
-      securesystemslib.pyca_crypto_keys._generate_derived_key('pw')
+      securesystemslib.rsa_keys._generate_derived_key('pw')
 
     # Store the derived key info in a dictionary, the object expected
     # by the non-public _encrypt() routine.
@@ -606,7 +604,7 @@ class TestInterfaceFunctions(unittest.TestCase):
     # Convert the key object to json string format and encrypt it with the
     # derived key.
     encrypted_key = \
-      securesystemslib.pyca_crypto_keys._encrypt(json.dumps(imported_ecdsa_key),
+      securesystemslib.rsa_keys._encrypt(json.dumps(imported_ecdsa_key),
           derived_key_information)
 
     with open(ecdsa_keypath, 'wb') as file_object:
